package com.ruoyi.goods.mapper;

import java.util.List;
import com.ruoyi.goods.domain.TCanteenClassify;

/**
 * 菜单类型Mapper接口
 * 
 * @author ruoyi
 * @date 2025-04-22
 */
public interface TCanteenClassifyMapper 
{
    /**
     * 查询菜单类型
     * 
     * @param classifyId 菜单类型主键
     * @return 菜单类型
     */
    public TCanteenClassify selectTCanteenClassifyByClassifyId(Long classifyId);

    /**
     * 查询菜单类型列表
     * 
     * @param tCanteenClassify 菜单类型
     * @return 菜单类型集合
     */
    public List<TCanteenClassify> selectTCanteenClassifyList(TCanteenClassify tCanteenClassify);

    /**
     * 新增菜单类型
     * 
     * @param tCanteenClassify 菜单类型
     * @return 结果
     */
    public int insertTCanteenClassify(TCanteenClassify tCanteenClassify);

    /**
     * 修改菜单类型
     * 
     * @param tCanteenClassify 菜单类型
     * @return 结果
     */
    public int updateTCanteenClassify(TCanteenClassify tCanteenClassify);

    /**
     * 删除菜单类型
     * 
     * @param classifyId 菜单类型主键
     * @return 结果
     */
    public int deleteTCanteenClassifyByClassifyId(Long classifyId);

    /**
     * 批量删除菜单类型
     * 
     * @param classifyIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTCanteenClassifyByClassifyIds(Long[] classifyIds);
}
